import * as request from 'request';
import { BaseRequestProcessor } from './BaseRequestProcessor';
import { IPatchBodyItem } from '../interfaces';
export declare class APIRequestProcessor extends BaseRequestProcessor {
    /**
     * Make request
     * @param options
     */
    makeRequest(options: request.OptionsWithUrl): Promise<any>;
    /**
     * Make GET request
     * @param path
     * @param [queryParameters]
     */
    get(path: string, queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make POST request
     * @param path
     * @param body
     * @param [queryParameters]
     */
    post(path: string, body: any, queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make PUT request
     * @param path
     * @param body
     * @param [queryParameters]
     */
    put(path: string, body: any, queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make PATCH request (json patch).
     * If you want to just simple merge objects - use `merge` method instead.
     * @see https://tools.ietf.org/html/rfc6902
     * @param path
     * @param body
     * @param [queryParameters]
     */
    patch(path: string, body: IPatchBodyItem[], queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make PATCH request (json merge)
     * @see https://tools.ietf.org/html/rfc7386
     * @param path
     * @param body
     * @param [queryParameters]
     */
    merge(path: string, body: any, queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make PATCH request
     * @param path
     * @param [queryParameters]
     */
    delete(path: string, queryParameters?: {
        [key: string]: number | string | undefined;
    }): Promise<any>;
    /**
     * Make k8s GET requests sequence to fetch all records
     * @param path
     * @param queryParameters
     */
    getAll(path: string, queryParameters?: {
        limit?: number | string;
        continue?: string;
        [key: string]: number | string | undefined;
    }): Promise<{
        resourceVersion: string;
        items: any[];
    }>;
}
