"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const util_1 = require("util");
const fs_1 = require("fs");
const Debug = require("debug");
const debug = Debug('@fireblink/k8s-api-client');
class BaseRequestProcessor {
    /**
     * Update kube config
     * @param kubeConfig
     */
    updateConfig(kubeConfig) {
        debug(`request processor: updating kube config with custom one: ${JSON.stringify(kubeConfig)}`);
        this.kubeConfig = kubeConfig;
    }
    /**
     * Load kube config
     */
    loadConfig() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.kubeConfig) {
                debug(`request processor: returning cached config`);
                return this.kubeConfig;
            }
            debug(`request processor: loading config`);
            const kc = new models_1.KubeConfig();
            yield kc.load();
            this.kubeConfig = kc;
            return kc;
        });
    }
    /**
     * Update request options based on kube config
     * @param options
     */
    updateRequestOptions(options) {
        return __awaiter(this, void 0, void 0, function* () {
            debug(`request processor: updating request option based on kube config`);
            const kc = yield this.loadConfig();
            if (kc.cluster.cluster['certificate-authority-data']) {
                options.ca = Buffer.from(kc.cluster.cluster['certificate-authority-data'], 'base64');
            }
            else if (kc.cluster.cluster['certificate-authority']) {
                options.ca = yield util_1.promisify(fs_1.readFile)(kc.cluster.cluster['certificate-authority']);
            }
            if (kc.user.user['client-certificate-data']) {
                options.cert = Buffer.from(kc.user.user['client-certificate-data'], 'base64');
            }
            else if (kc.user.user['client-certificate']) {
                options.cert = yield util_1.promisify(fs_1.readFile)(kc.user.user['client-certificate']);
            }
            if (kc.user.user['client-key-data']) {
                options.key = Buffer.from(kc.user.user['client-key-data'], 'base64');
            }
            else if (kc.user.user['client-key']) {
                options.key = yield util_1.promisify(fs_1.readFile)(kc.user.user['client-key']);
            }
            if (kc.user.user.token) {
                if (!options.headers) {
                    options.headers = {};
                }
                options.headers.Authorization = 'Bearer ' + kc.user.user.token;
            }
            if (kc.cluster.cluster['insecure-skip-tls-verify']) {
                options.rejectUnauthorized = false;
            }
            if (kc.user.user.username && kc.user.user.password) {
                options.auth = {
                    username: kc.user.user.username,
                    password: kc.user.user.password,
                };
            }
        });
    }
}
exports.BaseRequestProcessor = BaseRequestProcessor;
//# sourceMappingURL=BaseRequestProcessor.js.map